isDark property
bool
get
isDark
Checks if the color is dark based on its luminance value.
Implementation
bool get isDark => computeLuminance() < 0.5;
Checks if the color is dark based on its luminance value.
bool get isDark => computeLuminance() < 0.5;